@@ -1,23 +1,11 @@
-from autoselenium import Firefox
-from requests import get
-from selenium.common.exceptions import TimeoutException
-from selenium.webdriver.common.action_chains import ActionChains
-from selenium.webdriver.common.by import By
-from selenium.webdriver.common.keys import Keys
-from selenium.webdriver.firefox.options import Options
-from selenium.webdriver.remote.webelement import WebElement
-from selenium.webdriver.support import expected_conditions as EC
-from selenium.webdriver.support.ui import WebDriverWait
-from simpler.format import human_seconds, human_bytes
-from sys import stdout
-from threading import Thread
-from time import sleep, time
-from traceback import print_exc
-from typing import Dict, Optional, Tuple, Union
-from urllib.request import urlopen
+from typing import Dict, Optional, Tuple
 
 def download_file(url, path=None, chunk_size=10**5, show_progress=True) -> str:
 	''' Downloads a file keeping track of the progress. Returns the output path. '''
+	from requests import get
+	from simpler.format import human_seconds, human_bytes
+	from sys import stdout
+	from time import time
 	if path is None: path = url.split('/')[-1]
 	r = get(url, stream=True)
 	total_bytes = int(r.headers.get('content-length'))
@@ -42,18 +30,24 @@ def download_file(url, path=None, chunk_size=10**5, show_progress=True) -> str:
 
 class DownloaderPool:
 
-	def __init__(self, num_workers=100, download_method=lambda url: urlopen(url, timeout=5).read()):
+	def __init__(self, num_workers=100, download_method=None):
 		self.num_workers = num_workers
 		self.pending_urls = []
 		self.responses = {}
 		self.workers = None
-		self.download_method = download_method
+		if download_method is None:
+			from urllib.request import urlopen
+			self.download_method = lambda url: urlopen(url, timeout=5).read()
+		else:
+			self.download_method = download_method
 
 	def spawn_workers(self):
+		from threading import Thread
 		self.workers = [Thread(target=self.download_worker) for _ in range(self.num_workers)]
 		[w.start() for w in self.workers]
 
 	def download_worker(self):
+		from traceback import print_exc
 		while len(self.pending_urls):
 			url = self.pending_urls.pop()
 			try:
@@ -81,6 +75,7 @@ _throttle_last = 0
 def throttle(seconds: float = 1) -> None:
 	''' Sleeps the thread so that the function is called every X seconds. '''
 	global _throttle_last
+	from time import sleep, time
 	now = time()
 	remaining = _throttle_last + seconds - now
 	if remaining > 0:
@@ -95,6 +90,8 @@ class Driver:
 	_YEAR_SECONDS = 365.4 * 24 * 3600
 
 	def __init__(self, timeout: int = 3, keystroke_delay: int = .005, headless: bool = True, disable_flash: bool = True, disable_images: bool = True, language: str = 'en-US, en'):
+		from autoselenium import Firefox
+		from selenium.webdriver.firefox.options import Options
 		options = Options()
 		options.set_preference('intl.accept_languages', language)
 		self.driver = Firefox(headless=headless, disable_flash=disable_flash, disable_images=disable_images, options=options)
@@ -102,6 +99,7 @@ class Driver:
 		self.keystroke_delay = keystroke_delay
 
 	def browse(self, path: str):
+		from selenium.webdriver.support.ui import WebDriverWait
 		self.driver.get(path)
 		WebDriverWait(self.driver, self.timeout).until(lambda d: d.execute_script('return document.readyState') == 'complete')
 		self.driver.execute_script('var CONSOLE_MESSAGES = [];%s' % ';'.join(
@@ -110,6 +108,10 @@ class Driver:
 		))
 
 	def wait(self, element: str, message: str = 'Timeout waiting for element: ', raise_errors=True) -> None:
+		from selenium.common.exceptions import TimeoutException
+		from selenium.webdriver.common.by import By
+		from selenium.webdriver.support import expected_conditions as EC
+		from selenium.webdriver.support.ui import WebDriverWait
 		try:
 			WebDriverWait(self.driver, self.timeout).until(EC.presence_of_element_located((By.CSS_SELECTOR, element)))
 			return True
@@ -118,7 +120,8 @@ class Driver:
 				raise AssertionError(message + element) from e
 		return False
 
-	def select(self, element: Union[str, WebElement], wait: bool = True, all: bool = False, raise_errors: bool = None) -> WebElement:
+	def select(self, element, wait: bool = True, all: bool = False, raise_errors: bool = None):
+		from selenium.webdriver.remote.webelement import WebElement
 		if isinstance(element, WebElement): return element
 		found = self.wait(element, raise_errors=not all if raise_errors is None else raise_errors) if wait else False
 		if all:
@@ -126,7 +129,10 @@ class Driver:
 		elif found:
 			return self.driver.find_element_by_css_selector(element)
 
-	def write(self, element: Union[str, WebElement], text: str, clear: bool = False) -> None:
+	def write(self, element, text: str, clear: bool = False) -> None:
+		from selenium.webdriver.common.action_chains import ActionChains
+		from selenium.webdriver.common.keys import Keys
+		from time import sleep
 		element = self.select(element)
 		if clear:
 			self.click(element)
@@ -136,31 +142,36 @@ class Driver:
 			sleep(self.keystroke_delay)
 
 	def press(self, text: str):
+		from selenium.webdriver.common.action_chains import ActionChains
+		from time import sleep
 		for char in text:
 			ActionChains(self.driver).send_keys(self.translate(char)).perform()
 			sleep(self.keystroke_delay)
 
-	def click(self, element: Union[str, WebElement]) -> None:
+	def click(self, element) -> None:
 		self.select(element).click()
 
-	def hover(self, element: Union[str, WebElement]) -> None:
+	def hover(self, element) -> None:
+		from selenium.webdriver.common.action_chains import ActionChains
 		ActionChains(self.driver).move_to_element(self.select(element)).perform()
 
-	def focus(self, element: Union[str, WebElement]) -> None:
+	def focus(self, element) -> None:
+		from selenium.webdriver.common.action_chains import ActionChains
 		ActionChains(self.driver).move_to_element(self.select(element)).click().perform()
 
-	def drag(self, element: Union[str, WebElement], x_offset: int = 0, y_offset: int = 0) -> None:
+	def drag(self, element, x_offset: int = 0, y_offset: int = 0) -> None:
+		from selenium.webdriver.common.action_chains import ActionChains
 		ActionChains(self.driver).drag_and_drop_by_offset(self.select(element), x_offset, y_offset).perform()
 
-	def scroll(self, element: Union[str, WebElement], x_delta: float = 0, y_delta: float = 0, mouse_x: float = 0, mouse_y: float = 0) -> None:
+	def scroll(self, element, x_delta: float = 0, y_delta: float = 0, mouse_x: float = 0, mouse_y: float = 0) -> None:
 		self.driver.execute_script('''arguments[0].dispatchEvent(new WheelEvent("wheel", { bubbles: true,
 			deltaX: arguments[1], deltaY: arguments[2], clientX: arguments[3], clientY: arguments[4]
 		}))''', self.select(element), x_delta, y_delta, mouse_x, mouse_y)
 
-	def scroll_into_view(self, element: Union[str, WebElement]):
+	def scroll_into_view(self, element):
 		self.driver.execute_script('arguments[0].scrollIntoView({"block":"center"});', self.select(element))
 
-	def attribute(self, element: Union[str, WebElement], attribute: str, value: Optional[str] = None) -> Optional[str]:
+	def attribute(self, element, attribute: str, value: Optional[str] = None) -> Optional[str]:
 		args = [self.select(element), attribute]
 		if value is None:
 			script = 'return !arguments[0].hasAttribute(arguments[1]) ? null : arguments[0].getAttribute(arguments[1])'
@@ -169,7 +180,7 @@ class Driver:
 			args.append(value)
 		return self.driver.execute_script(script, *args)
 
-	def style(self, element: Union[str, WebElement], property: str, value: Optional[str] = None) -> Optional[str]:
+	def style(self, element, property: str, value: Optional[str] = None) -> Optional[str]:
 		args = [self.select(element), property]
 		if value is None:
 			script = 'return getComputedStyle(arguments[0])[arguments[1]]'
@@ -178,10 +189,10 @@ class Driver:
 			args.append(value)
 		return self.driver.execute_script(script, *args)
 
-	def bounding_box(self, element: Union[str, WebElement]) -> Dict[str, float]:
+	def bounding_box(self, element) -> Dict[str, float]:
 		return self.driver.execute_script('return arguments[0].getBoundingClientRect()', self.select(element))
 
-	def has_class(self, element: Union[str, WebElement], class_name: str) -> bool:
+	def has_class(self, element, class_name: str) -> bool:
 		return self.driver.execute_script(
 			'return arguments[0].classList.contains(arguments[1])',
 			self.select(element),
@@ -189,6 +200,7 @@ class Driver:
 		)
 
 	def cookie(self, name: str, value: Optional[str] = None, delete: bool = False) -> Optional[str]:
+		from time import time
 		if delete:
 			self.driver.delete_cookie(name)
 		elif value is None:
@@ -199,13 +211,14 @@ class Driver:
 	def clear_cookies(self):
 		self.driver.delete_all_cookies()
 
-	def box(self, element: Union[str, WebElement]) -> Tuple[float, float]:
+	def box(self, element) -> Tuple[float, float]:
 		res = self.driver.execute_script('return arguments[0].getBoundingClientRect()', self.select(element))
 		res['center_left'] = res['left'] + res['width'] / 2
 		res['center_top'] = res['top'] + res['height'] / 2
 		return res
 
 	def translate(self, char: str) -> str:
+		from selenium.webdriver.common.keys import Keys
 		if char == '\t':
 			return Keys.TAB
 		elif char == '\n':
